// import * as dd from 'dingtalk-jsapi'
import complexPicker from 'dingtalk-jsapi/api/biz/contact/complexPicker'
import setRight from 'dingtalk-jsapi/api/biz/navigation/setRight'
import setTitle from 'dingtalk-jsapi/api/biz/navigation/setTitle';

import requestAuthCode from 'dingtalk-jsapi/api/runtime/permission/requestAuthCode'
import requestOperateAuthCode from 'dingtalk-jsapi/api/runtime/permission/requestOperateAuthCode'

import chooseImage from 'dingtalk-jsapi/api/biz/util/chooseImage'

import { getENV } from "dingtalk-jsapi/lib/env";
import { compareVersion } from "dingtalk-jsapi/lib/sdk";

import * as dd from 'dingtalk-jsapi/lib/sdk/sdkLib'
import store from '@/store';

// import {} from 'dingtalk-jsapi/lib/packages'

// 公司CorpId
const CorpId = 'dingf1b2e9ddf9d214e224f2f5cc6abecb85' /* eslint-disable-line */

// 公司APIToken
const ApiToken = '43c2466a53613d9088e6364d554500cd' /* eslint-disable-line */

// 微应用ID
const AppId = '2796673629' /* eslint-disable-line */

export const { platform, version, appType } = getENV()

export function isAuthSDKSupport() {
    return compareVersion(version, '6.0.5')
}

/**
 * 查询钉钉通讯录
 * @param {Object} options 通讯录配置
 * @returns Promise pindding
 */
export function dingtalkComplexPicker (options) {
    return new Promise((resove, reject) => {
        complexPicker({
            title:"测试标题",            //标题
            corpId: CorpId,              //企业的corpId
            multiple:true,            //是否多选
            limitTips:"超出了",          //超过限定人数返回提示
            maxUsers:1000,            //最大可选人数
            pickedUsers:[],            //已选用户
            pickedDepartments:[],          //已选部门
            disabledUsers:[],            //不可选用户
            disabledDepartments:[],        //不可选部门
            requiredUsers:[],            //必选用户（不可取消选中状态）
            requiredDepartments:[],        //必选部门（不可取消选中状态）
            appId:158,              //微应用Id，企业内部应用查看AgentId
            permissionType:"xxx",          //可添加权限校验，选人权限，目前只有GLOBAL这个参数
            responseUserOnly:false,        //返回人，或者返回人和部门
            startWithDepartmentId:0 ,   //仅支持0和-1,
            ...options,
            onSuccess: function(result) {
                /**
                {
                    selectedCount:1,                              //选择人数
                    users:[{"name":"","avatar":"","emplId ":""}]，//返回选人的列表，列表中的对象包含name（用户名），avatar（用户头像），emplId（用户工号）三个字段
                    departments:[{"id":,"name":"","number":}]//返回已选部门列表，列表中每个对象包含id（部门id）、name（部门名称）、number（部门人数）
                }
                */
                resove(result)
            },
           onFail : function(err) {
            reject(err)
           }
        });
    })
}


/**
 * @description 设置导航栏右侧单按钮
 */
export function settingNavigationRight ({
    show = true,
    control = false,
    text = '我的XX',
    callback = () => {},
    callbackErr = () => {}
}) {
    setRight({
        show,
        control,
        text,
        onSuccess: (result) => {
            callback && callback(result)
        },
        onFail: (err) => {
            callbackErr && callbackErr(err)
        }
    })
}

/**
 * @description 设置导航栏标题
 */
// FIXME: 需要修改入参
export function settingNavigationTitle ({
    title = '默认标题',
    callback
}) {
    setTitle({
        title,
        onSuccess: result => {
            callback && callback(result)
        }
    })
}

/**
 * @description 获取微登录免授权码-无感操作 (only 5min life)
 */
export function getRequestAuthCode () {
    return new Promise((resolve, reject) => {
        requestAuthCode({
            corpId: CorpId,
            onSuccess: function(result) {
                resolve(result.code)
            },
            onFail : function(err) {
                console.log(err);
                reject(err)
            }
        })
    })
}

/**
 * @description 获取登录授权-有交互方式
 */
export function getRequestOperateAuthCode () {
    return new Promise((resolve, reject) => {
        requestOperateAuthCode({
            corpId: CorpId,
            agentId: AppId,
            onSuccess: function(result) {
                /*{
                    code: 'hYLK98jkf0m' //string authCode
                }*/
                resolve(result)
            },
            onFail : function(err) {
                reject(err)
            }
         
        })
    })
}


/**
 * 
 * @tips: 需要鉴权
 * @param {Object} options 配置`chooseImage`的选项
 * @returns 选中的图片
 */
export function getChooseImages (options) {
    const {
        count = 1,
        secret = false,
        sourceType =  ['camera'],
        position = 'back'
    } = options
    // sourceType =  ['camera','album']
    return new Promise((resolve, reject) => {
        chooseImage({
            count, // 可以选择几张图片
            secret,
            sourceType, // 选择图片或者拍照
            position,
            onSuccess: (res) => {
                resolve(res)
            },
            onFail:(err) =>{
                reject(err)
            }
        })
    })
}

/**
 * @description dingtalk 鉴权
 * @param {object} options jsApiList, errorCallback, readyCallback
 */
export function waitAuthentication (options) {
    (async function(d, ops){
        "use strict";

        const {
            jsApiList = [],

            errorCallback,
            readyCallback,
        } = ops || {}

        const {
            timeStamp,
            nonceStr,
            signature
        } = await store.dispatch('ddtalk/authentication', {
            href: window.location.origin // 网站源网址, 不包含#号与后边内容
        })

        d.config({
            agentId: AppId, // 必填，微应用ID
            corpId: CorpId,//必填，企业ID
            timeStamp, // 必填，生成签名的时间戳
            nonceStr, // 必填，自定义固定字符串。
            signature, // 必填，签名
            type: 0,   //选填。0表示微应用的jsapi,1表示服务窗的jsapi；不填默认为0。该参数从dingtalk.js的0.8.3版本开始支持
            jsApiList // 必填，需要使用的jsapi列表，注意：不要带dd。
        })

        d.ready(() => {
            readyCallback && readyCallback()
        })

        d.error((error) => {
            errorCallback && errorCallback(error)
        })
    })(dd, options);
}