

import { getStringTye } from '@/utils/util'
import indexComponentsMixins from './js/IndexComponentsMixins'
import { getApproveFlowPath } from '@/api/approveflow'

export default {
    mixins: [
        indexComponentsMixins
    ],
    props: {
        editData: {
            type: Object,
            default: () => (null)
        },
        editId: {
            type: Number,
            default: 0
        },
        flag: {
            type: String,
            validator: flag => (['', 'info', 'approve'].includes(flag)),
        }
    },
    data () {
        return {
            approvePeople: [], // 审核人员
            copyPeople: [], // 抄送人
            isCopy: undefined, // 是否可修改抄送人
        }
    },

    methods: {
        /**
         * @description 普通申请人获取的默认审核流程数据
         *  */
        async getCommonFlowPathData (options = {}) {
            try {
                let module = this.module
                const params = {
                    module
                }

                // NOTE: moduel = [5, 6]时，需要填写 `flow_item`字段。 取值 `options.flow_item`; 获取审批流程
                if ([5, 6].includes(module) && options.flow_item) params['flow_item'] = options.flow_item
                const res = await getApproveFlowPath(params)

                if (res.code === 1) {
                    /*
                    [{
                        userid: string,
                        avatar: string,
                        name: string
                    }]
                     */
                    const { 
                        approve_user = [],
                        copy_user = [],
                        is_copy = "0"
                    } = res.data
                    this.isCopy = is_copy
                    this.approvePeople = approve_user
                    this.copyPeople = copy_user

                }
            } catch (e) {
                console.log(e);
            }
        },

        /**
         * @description 基础校验是否为空, callback 可以自定义继续判断
         * @param {Object} param0 { mapTxt, requiredKey, data}
         * @param {Function} callback (data, hasEmpty, hasKey) => ([hasEmpty, hasKey, [toast,]])
         * @returns Boolean
         */
        __validtor__ ({ mapTxt, requiredKey, data  }, callback) {
            // let requiredKey = [
            //     'somekey'
            // ]
            // let mapTxt = {
            //      'somekey': 'something'
            // }
            let requiredKeyLength = requiredKey.length
            let hasEmpty = false
            let hasKey = ''

            for(let i = 0; i < requiredKeyLength; i++) {
                let key = requiredKey[i]
                let val = data[key]
                let type = getStringTye(val)
                
                if (type === 'Number' && !isNaN(val)) continue
                else if (type === 'Array' && val.length) continue
                else if (type === 'String' && val) continue
                else {
                    hasKey = key
                    hasEmpty = true
                    break
                }
            }

            // NOTE: 回调是为了判断当某值需要满足上游字段必填才出现的判断
            // 参考文件`IndexType5`的 `validate`函数
            let customToast = ''
            if (callback) {
                const [hEmpty, hKey, toastContext] = callback(data, hasEmpty, hasKey)
                hasEmpty = hEmpty
                hasKey = hKey
                customToast = toastContext
            }

            if (customToast) {
                this.$toast(customToast)
                return true
            } else if (hasEmpty) {
                this.$toast(mapTxt[hasKey] + '为空')
                return true
            }
        },

        /**
         * @description 跳转我的申请列表页面
         */
        __jump2apply_state__ () {
            this.$router.push({
                name: 'ApplyState',
                query: {
                    type: this.module
                }
            })
        }
    },
    watch: {
        editData: {
            handler (vals) {
                if (vals) this.handleFormatEditData(vals)
            },
            deep: true,
            immediate: true
        }
    }
}